# IFTAS CARIAD DNI Dashboard

A dashboard application for managing API access to the [FediCheck OSS - ActivityPub Denylist Service](https://github.com/iftas-org/Fedicheck-OSS). This dashboard allows administrators to monitor usage, manage API keys, and control access levels for third-party services.

## Features

- **API Key Management**
  - Create new API keys with specific permission levels
  - View and monitor existing API keys
  - Revoke access when needed
  - Set custom permissions per key

- **Usage Monitoring**
  - Track total requests per API key
  - Monitor usage across different DNI threshold levels (DNI, DNI+51, DNI+66, DNI+80)
  - View usage statistics and trends

- **Access Control**
  - Secure admin login
  - Manage different permission levels:
    - Basic DNI access
    - DNI+51 threshold access
    - DNI+66 threshold access
    - DNI+80 threshold access

## Technology Stack

- Next.js 14 (App Router)
- TypeScript
- Tailwind CSS
- Recharts for data visualization
- Shadcn/ui components

## Getting Started

1. **Clone the Denylist Service Repository**:  
   Ensure you have the FediCheck Denylist Service cloned and set up. Follow the instructions in the [FediCheck Denylist Service repository](https://github.com/your-repo/fedicheck-denylist-service) to complete the setup.

2. **Generate the Admin Key**:  
   Navigate to the `app/scripts` directory in the Denylist Service repository and run the following command to generate the admin key:
   ```bash
   node setup-admin-key.js

3. Clone this repository:
```bash
git clone [repository-url]
```

4. Install dependencies:
```bash
npm install
```

5. Set up environment variables:
```bash
cp .env.example .env.local
```

6. Run the development server:
```bash
npm run dev
```

7. Open [http://localhost:3000](http://localhost:3000) with your browser to access the dashboard.

## Authentication

The dashboard requires authentication to access. Default credentials for development:
- Username: `admin`
- Password: `password`

**Note:** Make sure to change these credentials in production.

## API Integration

The dashboard integrates with the IFTAS CARIAD DNI service API endpoints:

- `/api/dni/keys` - API key management
- `/api/dni-dash/admin/stats/threshold-usage` - Usage statistics
- `/api/dni-dash/keys/[keyId]/details` - Individual key details

## Security Considerations

- All API keys are encrypted before storage
- Access tokens are required for all API endpoints
- Regular key rotation is recommended
- Monitor usage patterns for potential abuse

## Contributing

1. Fork the repository
2. Create your feature branch (`git checkout -b feature/AmazingFeature`)
3. Commit your changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

## License

GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007

## Support

For support or questions about the DNI service, please contact [support contact information].
