import { NextResponse } from 'next/server';

if (!process.env.API_URL) {
  throw new Error('API_URL is not defined in environment variables');
}

if (!process.env.ADMIN_KEY) {
  throw new Error('ADMIN_KEY is not defined in environment variables');
}

export async function DELETE(
  request: Request,
  { params }: { params: { keyId: string } }
) {
  try {
    const response = await fetch(
      `${process.env.API_URL}/api/v1/denylist/admin/api-keys/${params.keyId}`,
      {
        method: 'DELETE',
        headers: {
          'Content-Type': 'application/json',
          'X-Admin-Key': process.env.ADMIN_KEY as string,
        },
      }
    );

    if (!response.ok) {
      const errorData = await response.json();
      throw new Error(errorData.error || `HTTP error! status: ${response.status}`);
    }

    const data = await response.json();
    return NextResponse.json(data);
  } catch (error) {
    console.error('API Error:', error);
    return NextResponse.json(
      {
        success: false,
        message: error instanceof Error ? error.message : 'Failed to delete API key',
      },
      { status: 500 }
    );
  }
} 