import { NextResponse } from 'next/server'

if (!process.env.API_URL) {
  throw new Error('API_URL is not defined in environment variables')
}

if (!process.env.ADMIN_KEY) {
  throw new Error('ADMIN_KEY is not defined in environment variables')
}

export async function POST(request: Request) {
  try {
    const body = await request.json()

    const response = await fetch(`${process.env.API_URL}/api/v1/denylist/admin/api-keys/create`, {
      method: 'POST',
      headers: new Headers({
        'Content-Type': 'application/json',
        'X-Admin-Key': process.env.ADMIN_KEY || '',
      }),
      body: JSON.stringify(body),
    })

    const data = await response.json()
    return NextResponse.json(data)
  } catch (error) {
    console.error('API Error:', error)
    return NextResponse.json(
      { success: false, message: 'Failed to create API key' },
      { status: 500 }
    )
  }
} 