import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card'
import { Bar, BarChart, ResponsiveContainer, Tooltip, XAxis, YAxis } from 'recharts'

interface DailyRequest {
  date: string;
  'DNI': number;
  'DNI+51': number;
  'DNI+66': number;
  'DNI+80': number;
}

interface UsageByList {
  list: string;
  requests: number;
}

interface IpUsageData {
  ip_address: string;
  total_requests: number;
  requests_by_threshold: {
    '51%': number;
    '66%': number;
    '80%': number;
  };
  last_used: string;
}

interface DashboardChartsProps {
  dailyRequests: DailyRequest[];
  apiUsageByList: UsageByList[];
  topIpAddresses?: IpUsageData[];
}

export function DashboardCharts({ 
  dailyRequests, 
  apiUsageByList,
  topIpAddresses = [] 
}: DashboardChartsProps) {
  return (
    <div className="grid gap-4 md:grid-cols-2 lg:grid-cols-7 min-h-0">
      <Card className="col-span-4 flex flex-col">
        <CardHeader>
          <CardTitle>Total Requests by List Type</CardTitle>
        </CardHeader>
        <CardContent className="flex-1">
          <div className="h-[200px] w-full">
            <ResponsiveContainer width="100%" height="100%">
              <BarChart data={apiUsageByList}>
                <XAxis
                  dataKey="list"
                  stroke="#888888"
                  fontSize={12}
                  tickLine={false}
                  axisLine={false}
                />
                <YAxis
                  stroke="#888888"
                  fontSize={12}
                  tickLine={false}
                  axisLine={false}
                  tickFormatter={(value) => `${value}`}
                />
                <Tooltip />
                <Bar
                  dataKey="requests"
                  fill="#8884d8"
                  radius={[4, 4, 0, 0]}
                />
              </BarChart>
            </ResponsiveContainer>
          </div>
        </CardContent>
      </Card>

      <Card className="col-span-3 flex flex-col">
        <CardHeader>
          <CardTitle>Top IP Addresses</CardTitle>
        </CardHeader>
        <CardContent className="flex-1 overflow-auto">
          <div className="space-y-4">
            {topIpAddresses.map((ip) => (
              <div key={ip.ip_address} className="flex items-center">
                <div className="flex-1 space-y-1">
                  <p className="text-sm font-medium">{ip.ip_address}</p>
                  <div className="text-xs text-muted-foreground">
                    Last used: {new Date(ip.last_used).toLocaleDateString()}
                  </div>
                </div>
                <div className="text-right">
                  <p className="text-sm font-medium">{ip.total_requests.toLocaleString()}</p>
                  <p className="text-xs text-muted-foreground">requests</p>
                </div>
              </div>
            ))}
          </div>
        </CardContent>
      </Card>
    </div>
  );
} 